@@ -1,6 +1,7 @@
 from __future__ import print_function
 from datetime import datetime
 import itertools
+import logging
 from subprocess import Popen
 
 import matplotlib.pyplot as plt
@@ -10,6 +11,9 @@ from pyage.core.statistics import Statistics
 from pyage_forams.solutions.foram import Foram
 
 
+logger = logging.getLogger(__name__)
+
+
 class PlottingStatistics(Statistics):
     @Inject("environment")
     def __init__(self):
@@ -103,4 +107,11 @@ class CsvStatistics(Statistics):
         return entry
 
 
+class SimpleStatistics(Statistics):
+    @Inject("environment")
+    def __init__(self):
+        super(SimpleStatistics, self).__init__()
 
+    def update(self, step_count, agents):
+        if step_count % 15 == 0:
+            logger.info(self.environment.grid)
\ No newline at end of file
